supportsAuthenticate method

  1. @override
bool supportsAuthenticate()
override

Returns true if the platform implementation supports the authenticate method.

The default is true, but platforms that cannot support authenticate can override this to return false, throw UnsupportedError from authenticate, and provide a different, platform-specific authentication flow.

Implementation

@override
bool supportsAuthenticate() => false;