GoogleSignInPlugin class
Implementation of the google_sign_in plugin for Web.
- Inheritance
-
- Object
- PlatformInterface
- GoogleSignInPlatform
- GoogleSignInPlugin
Constructors
-
GoogleSignInPlugin({@visibleForTesting bool debugOverrideLoader = false, @visibleForTesting GisSdkClient? debugOverrideGisSdkClient, @visibleForTesting StreamController<
AuthenticationEvent> ? debugAuthenticationController}) - Constructs the plugin immediately and begins initializing it in the background.
Properties
-
authenticationEvents
→ Stream<
AuthenticationEvent> -
Returns a stream of authentication events.
no setteroverride
- autoDetectedClientId ↔ String?
-
Stores the client ID if it was set in a meta-tag of the page.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialized
→ Future<
void> -
A future that resolves when the plugin is fully initialized.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attemptLightweightAuthentication(
AttemptLightweightAuthenticationParameters params) → Future< AuthenticationResults?> ? -
Attempts to sign in without an explicit user intent.
override
-
authenticate(
AuthenticateParameters params) → Future< AuthenticationResults> -
Signs in with explicit user intent.
override
-
Whether or not authorization calls that could show UI must be called from
a user interaction, such as a button press, on the current platform.
override
-
clearAuthorizationToken(
ClearAuthorizationTokenParams params) → Future< void> -
Clears any token cache for the given access token.
override
-
clientAuthorizationTokensForScopes(
ClientAuthorizationTokensForScopesParameters params) → Future< ClientAuthorizationTokenData?> -
Returns the tokens used to authenticate other API calls from a client.
override
-
disconnect(
DisconnectParams params) → Future< void> -
Revokes all of the scopes that all signed in users granted, and then signs
them out.
override
-
init(
InitParameters params) → Future< void> -
Initializes the plugin with specified
params. You must call this method before calling other methods.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renderButton(
{GSIButtonConfiguration? configuration}) → Widget - Render the GSI button web experience.
-
serverAuthorizationTokensForScopes(
ServerAuthorizationTokensForScopesParameters params) → Future< ServerAuthorizationTokenData?> -
Returns the tokens used to authenticate other API calls from a server.
override
-
signOut(
SignOutParams params) → Future< void> -
Signs out previously signed in accounts.
override
-
supportsAuthenticate(
) → bool -
Returns true if the platform implementation supports the authenticate
method.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void -
Factory method that initializes the plugin with
GoogleSignInPlatform.