authenticate method
Signs in with explicit user intent.
This is intended to support the use case where the user has expressed an explicit intent to sign in.
Implementation
@override
Future<AuthenticationResults> authenticate(
AuthenticateParameters params,
) async {
throw UnimplementedError(
'authenticate is not supported on the web. '
'Instead, use renderButton to create a sign-in widget.',
);
}